Method: Mail::AttachmentsList#guess_encoding

Defined in:
lib/mail/attachments_list.rb

#guess_encodingObject

Uses the mime type to try and guess the encoding, if it is a binary type, or unknown, then we set it to binary, otherwise as set to plain text



91
92
93
94
95
96
97
# File 'lib/mail/attachments_list.rb', line 91

def guess_encoding
  if @mime_type && !@mime_type.binary?
    "7bit"
  else
    "binary"
  end
end