Method: Mail::Message#resent_sender

Defined in:
lib/mail/message.rb

#resent_sender(val = nil) ⇒ Object

Returns the Resent-Sender value of the mail object, as a single string of an address spec. A sender per RFC 2822 must be a single address, so you can not append to this address.

Example:

mail.resent_sender = 'Mikel <[email protected]>'
mail.resent_sender #=> '[email protected]'

Also allows you to set the value by passing a value as a parameter

Example:

mail.resent_sender 'Mikel <[email protected]>'
mail.resent_sender #=> '[email protected]'


958
959
960
# File 'lib/mail/message.rb', line 958

def resent_sender( val = nil )
  default :resent_sender, val
end