Method: Mail::Address#raw
- Defined in:
- lib/mail/elements/address.rb
#raw ⇒ Object
Returns the raw input of the passed in string, this is before it is passed by the parser.
36 37 38 |
# File 'lib/mail/elements/address.rb', line 36 def raw @data.raw end |