Method: Mail::Message#to
- Defined in:
- lib/mail/message.rb
#to(val = nil) ⇒ Object
Returns the To value of the mail object as an array of strings of address specs.
Example:
mail.to = 'Mikel <[email protected]>'
mail.to #=> ['[email protected]']
mail.to = 'Mikel <[email protected]>, [email protected]'
mail.to #=> ['[email protected]', '[email protected]']
Also allows you to set the value by passing a value as a parameter
Example:
mail.to 'Mikel <[email protected]>'
mail.to #=> ['[email protected]']
Additionally, you can append new addresses to the returned Array like object.
Example:
mail.to 'Mikel <[email protected]>'
mail.to << '[email protected]'
mail.to #=> ['[email protected]', '[email protected]']
1188 1189 1190 |
# File 'lib/mail/message.rb', line 1188 def to( val = nil ) default :to, val end |